/* Text clustering method, SKWIC algorithm implementation
 * Model class representing one word of a document
 * Authors: Roman Milos, Vladimir Bartik, May 2011
 */
package dip.model;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlID;

/**
 * Model class representing one word of a document
 * @author Roman
 */
@XmlAccessorType(XmlAccessType.NONE)
public class Slovo {

    public Slovo() {
    }
    //Term ID
    @XmlElement
    private int id = 0;
    //Term name
    @XmlElement
    @XmlID
    private String jmeno;
    //Occurence count of a term
    @XmlElement
    private int pocet = 1;
    //Term weight
    @XmlElement
    private double vaha = 0.0;

    /**
     * Gets the identifier of a word. 
     * @return integer value with the identifier
     */
    public int getId() {
        return id;
    }

    /**
     * Gets the identifier of a word. 
     * @param id integer value with the identifier
     */
    public void setId(int id) {
        this.id = id;

    }

    /**
     * Gets the weight of a word. 
     * @return double value with the weight
     */    
    public double getVaha() {
        return vaha;
    }

    /**
     * Sets the weight of a word. 
     * @param vaha double value with the weight
     */  
    public void setVaha(double vaha) {
        this.vaha = vaha;
    }
    
    /**
     * Gets the word name. 
     * @return string with a word name
     */
    public String getJmeno() {
        return jmeno;
    }
    
    /**
     * Sets the word name. 
     * @param jmeno string with a word name
     */
    public void setJmeno(String jmeno) {
        this.jmeno = jmeno;
    }

    /**
     * Gets the occurrence count of a word. 
     * @return integer value with occurrence count
     */    
    public int getPocet() {
        return pocet;
    }
    
    /**
     * Sets the occurrence count of a word. 
     * @param pocet integer value with occurrence count
     */  
    public void setPocet(int pocet) {
        this.pocet = pocet;
    }
    
    /**
     * Constructor
     */
    public Slovo(String jmeno) {
        this.jmeno = jmeno;
    }

    /**
     * Increments occurrence count of a word
     */
    public void inc() {
        pocet++;
    }

    /**
     * "hashCode" modification to act as a string.
     */
    @Override
    public int hashCode() {
        return jmeno.hashCode();

    }

    /**
     * "equals" modification to compare the words
     * @param obj object
     * @return boolean value
     */
    @Override
    public boolean equals(Object obj) {
        if (obj == null) {
            return false;
        }
        if (getClass() != obj.getClass()) {
            return false;
        }
        final Slovo other = (Slovo) obj;
        if ((this.jmeno == null) ? (other.jmeno != null) : !this.jmeno.equals(other.jmeno)) {
            return false;
        }
        return true;
    }
}
