/* 
 * Method for clustering text data, SKWIC algorithm implementation
 * View class generating the main menu
 * Created by: Roman Milos, Vladimir Bartik, May 2011
 */
package dip.pohled;

import dip.Main;
import dip.pohled.filtry.XMLFiltr;
import dip.kontroler.Gui;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.io.File;
import javax.swing.JFileChooser;
import javax.swing.JFrame;
import javax.swing.JMenu;
import javax.swing.JMenuBar;
import javax.swing.JMenuItem;
import javax.swing.JOptionPane;

/**
 * View class generating the main menu
 * @author Roman
 */
public class MojeMenu {

    /**
     * Creates the menu of the application, adds hot keys and listeners 
     * waiting for events from users.
     * @param okno a window, which will contain menu
     */
    public static void menuTab(JFrame okno) {
        final JFrame frame = okno;
        JMenuBar lista = new JMenuBar();                      
        okno.setJMenuBar(lista);                           

        //adding items to menu
        JMenu hlavni = new JMenu("File", true);
        JMenuItem hlavniImport = new JMenuItem("Xml Import");

        JMenuItem hlavniExport = new JMenuItem("Xml Export");
        JMenuItem hlavniKonec = new JMenuItem("Quit");
        hlavniImport.setAccelerator(javax.swing.KeyStroke.getKeyStroke(java.awt.event.KeyEvent.VK_I, java.awt.event.InputEvent.CTRL_MASK));
        hlavniExport.setAccelerator(javax.swing.KeyStroke.getKeyStroke(java.awt.event.KeyEvent.VK_E, java.awt.event.InputEvent.CTRL_MASK));
        hlavniKonec.setAccelerator(javax.swing.KeyStroke.getKeyStroke(java.awt.event.KeyEvent.VK_K, java.awt.event.InputEvent.CTRL_MASK));

        //placing items to the menu
        lista.add(hlavni);//- add(hlavni);
        hlavni.add(hlavniImport);
        hlavni.add(hlavniExport);
        hlavni.addSeparator();
        hlavni.add(hlavniKonec);

        JMenu napoveda = new JMenu("Help", true);
        JMenuItem oProgramu = new JMenuItem("About");

        lista.add(napoveda);//- add(napoveda);
        napoveda.add(oProgramu);

        hlavniExport.addActionListener(new ActionListener() {

            public void actionPerformed(ActionEvent e) {
                File soubor;
                try {
                    JFileChooser fc = new JFileChooser();
                    fc.setFileSelectionMode(JFileChooser.FILES_ONLY);
                    fc.setDialogTitle("Select XML file for export");
                    fc.setDialogType(JFileChooser.SAVE_DIALOG);
                    fc.setApproveButtonText("Save");

                    soubor = new java.io.File(".");
                    fc.setFileFilter(new XMLFiltr());
                    fc.setCurrentDirectory(soubor);

                    fc.showSaveDialog(frame);
                    soubor =
                            fc.getSelectedFile();
                    if (soubor == null) {
                        return;
                    }
                    Gui.getInstance().xmlExport(frame, soubor);
                } catch (Exception ee) {
                    Main.vyridVyjimku(new Exception("Unable to read file"));
                    return;

                }

            }
        });//ActionListener()
        hlavniImport.addActionListener(new ActionListener() {

            public void actionPerformed(ActionEvent e) {
                File soubor;
                try {
                    JFileChooser fc = new JFileChooser();
                    fc.setFileSelectionMode(JFileChooser.FILES_ONLY);
                    fc.setDialogTitle("Select XML file for import");
                    fc.setDialogType(JFileChooser.OPEN_DIALOG);
                    fc.setApproveButtonText("Open");

                    soubor = new java.io.File(".");

                    fc.setCurrentDirectory(soubor);
                    fc.setFileFilter(new XMLFiltr());
                    fc.showOpenDialog(frame);
                    soubor =
                            fc.getSelectedFile();
                    if (soubor == null) {
                        return;
                    }
                    Gui.getInstance().xmlImport(frame, soubor);
                } catch (Exception ee) {
                    Main.vyridVyjimku(new Exception("Unable to read file"));
                    return;

                }


            }
        });//ActionListener()
        hlavniKonec.addActionListener(new ActionListener() {

            public void actionPerformed(ActionEvent e) {
                frame.dispose();
            }
        });//ActionListener()
        oProgramu.addActionListener(new ActionListener() {

            public void actionPerformed(ActionEvent e) {
                String s = new String("SKWIC algorithm implementation. \nAuthors: Roman Milos, Vladimir Bartik");
                JOptionPane.showMessageDialog(null, s, "About", JOptionPane.INFORMATION_MESSAGE);
            }
        });//ActionListener()
    }
}
